OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Hakemistoon \"config\" kirjoittaminen ei onnistu!",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Jos haluat pitää config.php-tiedoston vain luku -muodossa, aseta valinnan \"config_is_read_only\" arvoksi true.",
    "See %s" : "Katso %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Sovelluksen %1$s tiedostoja ei korvattu oikein Varmista, että sen versio on yhteensopiva palvelimen kanssa.",
    "Sample configuration detected" : "Esimerkkimääritykset havaittu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "On havaittu, että esimerkkimäärityksen on kopioitu. Se voi rikkoa asennuksesi, eikä sitä tueta. Lue ohjeet ennen kuin muutat config.php tiedostoa.",
    "404" : "404",
    "The page could not be found on the server." : "Sivua ei löytynyt palvelimelta.",
    "Email verification" : "Sähköpostin vahvistus",
    "Click the following button to confirm your email." : "Napsauta seuraavaa painiketta vahvistaaksesi sähköpostiosoitteesi.",
    "Click the following link to confirm your email." : "Napsauta seuraavaa linkkiä vahvistaaksesi sähköpostiosoitteesi.",
    "Confirm your email" : "Vahvista sähköpostiosoitteesi",
    "Other activities" : "Muut toimet",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s tai sitä uudempi vaaditaan.",
    "PHP with a version lower than %s is required." : "PHP versiota %s alempi tarvitaan.",
    "%sbit or higher PHP required." : "%s-bit tai korkeampi PHP vaaditaan.",
    "The following architectures are supported: %s" : "Seuraavat arkkitehtuurit ovat tuettuja: %s",
    "The following databases are supported: %s" : "Seuraavat tietokannat ovat tuettuja: %s",
    "The command line tool %s could not be found" : "Komentorivityökalua %s ei löytynyt",
    "The library %s is not available." : "Kirjastoa %s ei ole käytettävissä.",
    "The following platforms are supported: %s" : "Seuraavat alustat ovat tuettuja: %s",
    "Server version %s or higher is required." : "Palvelinversio %s tai sitä uudempi vaaditaan.",
    "Server version %s or lower is required." : "Palvelinversio %s tai alhaisempi vaaditaan.",
    "Logged in user must be an admin" : "Sisäänkirjautuneen käyttäjän tulee olla ylläpitäjä",
    "Wiping of device %s has started" : "Laitteen %s tyhjennys aloitettiin",
    "Wiping of device »%s« has started" : "Laitteen »%s« tyhjennys aloitettiin",
    "»%s« started remote wipe" : "»%s« aloitti etätyhjennyksen",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Laite tai sovellus »%s« käynnisti etätyhjennyksen. Saat sähköpostin, kun toimenpide on valmistunut",
    "Wiping of device %s has finished" : "Laitteen %s tyhjennys valmistui",
    "Wiping of device »%s« has finished" : "Laitteen »%s« tyhjennys valmistui",
    "»%s« finished remote wipe" : "»%s« suoritti etätyhjennyksen",
    "Device or application »%s« has finished the remote wipe process." : "Laite tai sovellus »%s« on suorittanut etätyhjennyksen.",
    "Remote wipe started" : "Etätyhjennys aloitettiin",
    "A remote wipe was started on device %s" : "Laitteen %s etätyhjennys aloitettiin",
    "Remote wipe finished" : "Etätyhjennys valmistui",
    "The remote wipe on %s has finished" : "Etätyhjennys laitteella %s valmistui",
    "Authentication" : "Tunnistautuminen",
    "Unknown filetype" : "Tuntematon tiedostotyyppi",
    "Invalid image" : "Virheellinen kuva",
    "Avatar image is not square" : "Avatar-kuva ei ole neliö",
    "View profile" : "Näytä profiili",
    "today" : "tänään",
    "tomorrow" : "huomenna",
    "yesterday" : "eilen",
    "_in %n day_::_in %n days_" : ["%n päivän päästä","%n päivän päästä"],
    "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
    "next month" : "ensi kuussa",
    "last month" : "viime kuussa",
    "_in %n month_::_in %n months_" : ["%n kuukauden päästä","%n kuukauden päästä"],
    "_%n month ago_::_%n months ago_" : ["%n kuukausi sitten","%n kuukautta sitten"],
    "next year" : "ensi vuonna",
    "last year" : "viime vuonna",
    "_in %n year_::_in %n years_" : ["%n vuoden päästä","%n vuoden päästä"],
    "_%n year ago_::_%n years ago_" : ["%n vuosi sitten","%n vuotta sitten"],
    "_in %n hour_::_in %n hours_" : ["%n tunnin päästä","%n tunnin päästä"],
    "_%n hour ago_::_%n hours ago_" : ["%n tunti sitten","%n tuntia sitten"],
    "_in %n minute_::_in %n minutes_" : ["%n minuutin päästä","%n minuutin päästä"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuutti sitten","%n minuuttia sitten"],
    "in a few seconds" : "muutaman sekunnin päästä",
    "seconds ago" : "sekunteja sitten",
    "Empty file" : "Tyhjä tiedosto",
    "File already exists" : "Tiedosto on jo olemassa",
    "Invalid path" : "Virheellinen polku",
    "Failed to create file from template" : "Tiedoston luominen mallipohjasta epäonnistui",
    "Templates" : "Mallipohjat",
    "File name is a reserved word" : "Tiedoston nimi on varattu sana",
    "File name contains at least one invalid character" : "Tiedoston nimi sisältää ainakin yhden virheellisen merkin",
    "File name is too long" : "Tiedoston nimi on liian pitkä",
    "Dot files are not allowed" : "Pistetiedostot eivät ole sallittuja",
    "Empty filename is not allowed" : "Tiedostonimi ei voi olla tyhjä",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Sovellusta \"%s\" ei voi asentaa, koska appinfo-tiedostoa ei voi loi lukea.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Sovellusta \"%s\" ei voi asentaa, koska se ei ole yhteensopiva tämän palvelinversion kanssa.",
    "__language_name__" : "suomi",
    "This is an automatically sent email, please do not reply." : "Tämä on automaattisesti lähetetty viesti. Älä vastaa tähän viestiin.",
    "Help" : "Ohje",
    "Appearance and accessibility" : "Ulkoasu ja saavutettavuus",
    "Apps" : "Sovellukset",
    "Personal settings" : "Henkilökohtaiset asetukset",
    "Administration settings" : "Ylläpitäjän asetukset",
    "Settings" : "Asetukset",
    "Log out" : "Kirjaudu ulos",
    "Users" : "Käyttäjät",
    "Email" : "Sähköposti",
    "Mail %s" : "Lähetä sähköpostia %s",
    "Phone" : "Puhelin",
    "Call %s" : "Soita %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Näytä %s Twitterissä",
    "Website" : "Verkkosivu",
    "Visit %s" : "Käy sivustolla %s",
    "Address" : "Osoite",
    "Profile picture" : "Profiilikuva",
    "About" : "Tietoja",
    "Full name" : "Koko nimi",
    "Headline" : "Otsikko",
    "Organisation" : "Organisaatio",
    "Role" : "Rooli",
    "Unknown user" : "Tuntematon käyttäjä",
    "Additional settings" : "Lisäasetukset",
    "MySQL username and/or password not valid" : "MySQL-käyttäjätunnus ja/tai -salasana on väärin",
    "You need to enter details of an existing account." : "Anna olemassa olevan tilin tiedot.",
    "Oracle connection could not be established" : "Oracle-yhteyttä ei voitu muodostaa",
    "Oracle username and/or password not valid" : "Oraclen käyttäjätunnus ja/tai salasana on väärin",
    "PostgreSQL username and/or password not valid" : "PostgreSQL:n käyttäjätunnus ja/tai salasana on väärin",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole tuettu, joten %s ei toimi kunnolla tällä alustalla. Käytä omalla vastuulla!",
    "For the best results, please consider using a GNU/Linux server instead." : "Käytä parhaan lopputuloksen saamiseksi GNU/Linux-palvelinta.",
    "Set an admin username." : "Aseta ylläpitäjän käyttäjätunnus.",
    "Set an admin password." : "Aseta ylläpitäjän salasana.",
    "Sharing backend %s not found" : "Jakamisen taustaosaa %s ei löytynyt",
    "Sharing backend for %s not found" : "Jakamisen taustaosaa kohteelle %s ei löytynyt",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s jakoi kohteen »%2$s« kanssasi ja haluaa lisätä:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s jakoi kohteen »%2$s« kanssasi ja haluaa lisätä",
    "»%s« added a note to a file shared with you" : "»%s« lisäsi huomion jakamaasi tiedostoon",
    "Open »%s«" : "Avaa »%s«",
    "%1$s via %2$s" : "%1$s palvelun %2$s kautta",
    "You are not allowed to share %s" : "Oikeutesi eivät riitä kohteen %s jakamiseen.",
    "Cannot increase permissions of %s" : "Kohteen %s käyttöoikeuksien lisääminen ei onnistu",
    "Files cannot be shared with delete permissions" : "Tiedostoja ei voi jakaa poistamisoikeuksilla",
    "Files cannot be shared with create permissions" : "Tiedostoja ei voi jakaa luomisoikeuksilla",
    "Expiration date is in the past" : "Vanhenemispäivä on menneisyydessä",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Vanhenemispäivän voi asettaa korkeintaan %n päivään tulevaisuuteen","Vanhenemispäivän voi asettaa korkeintaan %n päivään tulevaisuuteen"],
    "Sharing is only allowed with group members" : "Jakaminen on sallittu vain ryhmäjäsenten kesken",
    "Sharing %s failed, because this item is already shared with user %s" : "Kohteen %s jakaminen epäonnistui, koska kohde on jo jaettu käyttäjän %s kanssa",
    "%1$s shared »%2$s« with you" : "%1$s jakoi kohteen »%2$s« kanssasi",
    "%1$s shared »%2$s« with you." : "%1$s jakoi kohteen »%2$s« kanssasi.",
    "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
    "The requested share does not exist anymore" : "Pyydettyä jakoa ei ole enää olemassa",
    "Could not find category \"%s\"" : "Luokkaa \"%s\" ei löytynyt",
    "Sunday" : "sunnuntai",
    "Monday" : "maanantai",
    "Tuesday" : "tiistai",
    "Wednesday" : "keskiviikko",
    "Thursday" : "torstai",
    "Friday" : "perjantai",
    "Saturday" : "lauantai",
    "Sun." : "Su",
    "Mon." : "Ma",
    "Tue." : "Ti",
    "Wed." : "Ke",
    "Thu." : "To",
    "Fri." : "Pe",
    "Sat." : "La",
    "Su" : "Su",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "Ke",
    "Th" : "To",
    "Fr" : "Pe",
    "Sa" : "La",
    "January" : "tammikuu",
    "February" : "helmikuu",
    "March" : "maaliskuu",
    "April" : "huhtikuu",
    "May" : "toukokuu",
    "June" : "kesäkuu",
    "July" : "heinäkuu",
    "August" : "elokuu",
    "September" : "syyskuu",
    "October" : "lokakuu",
    "November" : "marraskuu",
    "December" : "joulukuu",
    "Jan." : "Tammi",
    "Feb." : "Helmi",
    "Mar." : "Maalis",
    "Apr." : "Huhti",
    "May." : "Touko",
    "Jun." : "Kesä",
    "Jul." : "Heinä",
    "Aug." : "Elo",
    "Sep." : "Syys",
    "Oct." : "Loka",
    "Nov." : "Marras",
    "Dec." : "Joulu",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-'\"",
    "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
    "Username contains whitespace at the beginning or at the end" : "Käyttäjätunnus sisältää tyhjätilaa joko alussa tai lopussa",
    "Username must not consist of dots only" : "Käyttäjänimi ei voi koostua vain pisteistä",
    "Username is invalid because files already exist for this user" : "Käyttäjänimi on virheellinen koska tiedostoja on olemassa tälle käyttäjälle",
    "A valid password must be provided" : "Anna kelvollinen salasana",
    "The username is already being used" : "Käyttäjätunnus on jo käytössä",
    "Could not create user" : "Ei voitu luoda käyttäjää",
    "User disabled" : "Käyttäjä poistettu käytöstä",
    "Login canceled by app" : "Kirjautuminen peruttiin sovelluksen toimesta",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Sovellusta \"%1$s\" ei voi asentaa, koska seuraavat riippuvuudet eivät täyty: %2$s",
    "a safe home for all your data" : "turvallinen koti kaikille tiedostoillesi",
    "File is currently busy, please try again later" : "Tiedosto on parhaillaan käytössä, yritä myöhemmin uudelleen",
    "Cannot download file" : "Tiedostoa ei voi ladata",
    "Application is not enabled" : "Sovellusta ei ole otettu käyttöön",
    "Authentication error" : "Tunnistautumisvirhe",
    "Token expired. Please reload page." : "Valtuutus vanheni. Lataa sivu uudelleen.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tietokanta-ajureita (sqlite, mysql tai postgresql) ei ole asennettu.",
    "Cannot write into \"config\" directory." : "Ei voi kirjoittaa \"config\"-hakemistoon",
    "Cannot write into \"apps\" directory." : "Ei voi kirjoittaa \"apps\"-hakemistoon",
    "Cannot create \"data\" directory." : "Ei voi luoda \"data\"-hakemistoa",
    "Your data directory is not writable." : "Datahakemistosi ei ole kirjoitettavissa.",
    "Setting locale to %s failed." : "Maa-asetuston %s asettaminen epäonnistui.",
    "PHP module %s not installed." : "PHP-moduulia %s ei ole asennettu.",
    "Please ask your server administrator to install the module." : "Pyydä palvelimen ylläpitäjää asentamaan moduulin.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-asetusta \"%s\" ei ole asetettu arvoon \"%s\".",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> on asetettu arvoon <code>%s</code> odotetun arvon <code>0</code> sijaan.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Korjaa ongelma asettamalla ominaisuuden <code>mbstring.func_overload</code> arvoksi <code>0</code> php.ini-tiedostossa.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vähintään libxml2 2.7.0 vaaditaan. %s on asennettu.",
    "To fix this issue update your libxml2 version and restart your web server." : "Päivitä libxml2:n versio ja käynnistä http-palvelin uudelleen.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tämä johtuu todennäköisesti välimuistista tai kiihdyttimestä kuten Zend OPcachesta tai eAcceleratorista.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduulit on asennettu, mutta ovatko ne vieläkin listattu puuttuviksi?",
    "Please ask your server administrator to restart the web server." : "Pyydä palvelimen ylläpitäjää käynnistämään web-palvelin uudelleen.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Pyydä palvelimen ylläpitäjää tarkastamaan Nextcloudin määritykset.",
    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 vaaditaan.",
    "Please upgrade your database version." : "Päivitä tietokannan versio.",
    "Your data directory is readable by other users." : "Datahakemistosi on muiden käyttäjien luettavissa.",
    "Your data directory must be an absolute path." : "Datahakemiston tulee olla absoluuttinen polku.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Varmista että datahakemiston juuressa on tiedosto nimeltä \".ocdata\".",
    "Action \"%s\" not supported or implemented." : "Toiminto \"%s\" ei ole tuettu tai sitä ei ole toteutettu.",
    "Could not obtain lock type %d on \"%s\"." : "Lukitustapaa %d ei saatu kohteelle \"%s\".",
    "Storage unauthorized. %s" : "Tallennustila ei ole valtuutettu. %s",
    "Storage incomplete configuration. %s" : "Tallennustilan puutteellinen määritys. %s",
    "Storage connection error. %s" : "Tallennustilan yhteysvirhe. %s",
    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
    "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s",
    "%s enter the database username and name." : "%s anna tietokannan käyttäjätunnus ja nimi.",
    "%s enter the database username." : "%s anna tietokannan käyttäjätunnus.",
    "%s enter the database name." : "%s anna tietokannan nimi.",
    "%s you may not use dots in the database name" : "%s et voi käyttää pisteitä tietokannan nimessä",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Vaikuttaa siltä, että tämä %s-instanssi toimii 32-bittisessä PHP-ympäristössä ja open_basedir-asetus on määritetty php.ini-tiedostossa. Tämä johtaa ongelmiin yli 4 gigatavun tiedostojen kanssa, eikä siksi ole suositeltavaa.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Poista open_basedir-asetus php.ini-tiedostosta tai vaihda 64-bittiseen PHP:hen.",
    "The user limit has been reached and the user was not created." : "Käyttäjäraja on tullut täyteen, joten käyttäjää ei luotu.",
    "Cannot read file" : "Tiedostoa ei voi lukea",
    "Cannot write into \"config\" directory" : "Hakemistoon \"config\" kirjoittaminen ei onnistu",
    "Cannot write into \"apps\" directory" : "Hakemistoon \"apps\" kirjoittaminen ei onnistu",
    "Cannot create \"data\" directory" : "Hakemiston \"data\" luominen ei onnistu",
    "Setting locale to %s failed" : "Maa-asetuksen %s asettaminen epäonnistui",
    "Please install one of these locales on your system and restart your webserver." : "Asenna ainakin yksi kyseisistä maa-asetuksista järjestelmään ja käynnistä http-palvelin uudelleen.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload on asetettu arvoon \"%s\" odotetun arvon \"0\" sijaan",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Korjaa tämä ongelma asettamalla <code>mbstring.func_overload</code> arvoon <code>0</code> php.ini-tiedostossasi",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 vaaditaan",
    "Please upgrade your database version" : "Päivitä tietokantasi versio",
    "Your data directory is readable by other users" : "Data-hakemisto on muiden käyttäjien luettavissa",
    "Your data directory must be an absolute path" : "Data-hakemiston tulee olla absoluuttinen polku",
    "Check the value of \"datadirectory\" in your configuration" : "Tarkista \"datadirectory\"-arvo asetuksistasi",
    "Your data directory is invalid" : "Datahakemistosi on virheellinen"
},
"nplurals=2; plural=(n != 1);");
